@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"io"
 	"io/ioutil"
+	"math"
 	"math/big"
 	"math/rand"
 	"os"
@@ -38,7 +39,7 @@ const (
 	PRINT_IF_NOT_NIL
 )
 
-const VERSION = "v1.4.1"
+const VERSION = "v1.5.0"
 
 const (
 	CLJ Dialect = iota
@@ -1728,6 +1729,58 @@ var procExit = func(args []Object) Object {
 	return NIL
 }
 
+var procIsNaN = func(args []Object) Object {
+	n := EnsureArgIsNumber(args, 0)
+	return Boolean{B: math.IsNaN(n.Double().D)}
+}
+
+var procAbs = func(args []Object) Object {
+	n := EnsureArgIsNumber(args, 0)
+	switch n := n.(type) {
+	case Double:
+		return Double{D: math.Abs(n.D)}
+	case *BigInt:
+		b := &big.Int{}
+		return &BigInt{b: b.Abs(n.b)}
+	case *BigFloat:
+		b := &big.Float{}
+		return &BigFloat{b: b.Abs(n.b)}
+	case *Ratio:
+		r := &big.Rat{}
+		return &Ratio{r: r.Abs(n.r)}
+	case Int:
+		x := n.I
+		if x < 0 {
+			x = -x
+		}
+		return Int{I: x}
+	}
+	panic(FailArg(n, "Number", 0))
+}
+
+var procIsInfinite = func(args []Object) Object {
+	n := EnsureArgIsNumber(args, 0)
+	return Boolean{B: math.IsInf(n.Double().D, 0)}
+}
+
+var procParseDouble = func(args []Object) Object {
+	s := EnsureArgIsString(args, 0)
+	d, err := strconv.ParseFloat(s.S, 64)
+	if err != nil {
+		return NIL
+	}
+	return Double{D: d}
+}
+
+var procParseLong = func(args []Object) Object {
+	s := EnsureArgIsString(args, 0)
+	i, err := strconv.ParseInt(s.S, 10, 64)
+	if err != nil {
+		return NIL
+	}
+	return Int{I: int(i)}
+}
+
 func PackReader(reader *Reader, filename string) ([]byte, error) {
 	var p []byte
 	packEnv := NewPackEnv()
